<?php

namespace Litecms\ManageIP\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\ManageIP\Http\Requests\ManageIPRequest;
use Litecms\ManageIP\Interfaces\ManageIPRepositoryInterface;
use Litecms\ManageIP\Models\ManageIP;

/**
 * Resource controller class for manage_i_p.
 */
class ManageIPResourceController extends BaseController
{

    /**
     * Initialize manage_i_p resource controller.
     *
     * @param type ManageIPRepositoryInterface $manage_i_p
     *
     * @return null
     */
    public function __construct(ManageIPRepositoryInterface $manage_i_p)
    {
        parent::__construct();
        $this->repository = $manage_i_p;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\ManageIP\Repositories\Criteria\ManageIPResourceCriteria::class);
    }

    /**
     * Display a list of manage_i_p.
     *
     * @return Response
     */
    public function index(ManageIPRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\ManageIP\Repositories\Presenter\ManageIPPresenter::class)
                ->$function();
        }

        $manage_i_ps = $this->repository->paginate();

        return $this->response->title(trans('manage_i_p::manage_i_p.names'))
            ->view('manage_i_p::manage_i_p.index', true)
            ->data(compact('manage_i_ps'))
            ->output();
    }

    /**
     * Display manage_i_p.
     *
     * @param Request $request
     * @param Model   $manage_i_p
     *
     * @return Response
     */
    public function show(ManageIPRequest $request, ManageIP $manage_i_p)
    {

        if ($manage_i_p->exists) {
            $view = 'manage_i_p::manage_i_p.show';
        } else {
            $view = 'manage_i_p::manage_i_p.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('manage_i_p::manage_i_p.name'))
            ->data(compact('manage_i_p'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new manage_i_p.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ManageIPRequest $request)
    {

        $manage_i_p = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('manage_i_p::manage_i_p.name')) 
            ->view('manage_i_p::manage_i_p.create', true) 
            ->data(compact('manage_i_p'))
            ->output();
    }

    /**
     * Create new manage_i_p.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ManageIPRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $manage_i_p                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('manage_i_p::manage_i_p.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('manage_i_p/manage_i_p/' . $manage_i_p->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/manage_i_p/manage_i_p'))
                ->redirect();
        }

    }

    /**
     * Show manage_i_p for editing.
     *
     * @param Request $request
     * @param Model   $manage_i_p
     *
     * @return Response
     */
    public function edit(ManageIPRequest $request, ManageIP $manage_i_p)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('manage_i_p::manage_i_p.name'))
            ->view('manage_i_p::manage_i_p.edit', true)
            ->data(compact('manage_i_p'))
            ->output();
    }

    /**
     * Update the manage_i_p.
     *
     * @param Request $request
     * @param Model   $manage_i_p
     *
     * @return Response
     */
    public function update(ManageIPRequest $request, ManageIP $manage_i_p)
    {
        try {
            $attributes = $request->all();

            $manage_i_p->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('manage_i_p::manage_i_p.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('manage_i_p/manage_i_p/' . $manage_i_p->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('manage_i_p/manage_i_p/' . $manage_i_p->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the manage_i_p.
     *
     * @param Model   $manage_i_p
     *
     * @return Response
     */
    public function destroy(ManageIPRequest $request, ManageIP $manage_i_p)
    {
        try {

            $manage_i_p->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('manage_i_p::manage_i_p.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('manage_i_p/manage_i_p/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('manage_i_p/manage_i_p/' . $manage_i_p->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple manage_i_p.
     *
     * @param Model   $manage_i_p
     *
     * @return Response
     */
    public function delete(ManageIPRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('manage_i_p::manage_i_p.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('manage_i_p/manage_i_p'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/manage_i_p/manage_i_p'))
                ->redirect();
        }

    }

    /**
     * Restore deleted manage_i_ps.
     *
     * @param Model   $manage_i_p
     *
     * @return Response
     */
    public function restore(ManageIPRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('manage_i_p::manage_i_p.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/manage_i_p/manage_i_p'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/manage_i_p/manage_i_p/'))
                ->redirect();
        }

    }

}
