<?php

namespace Litecms\ManageIP\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\ManageIP\Models\ManageIP;

class ManageIPPolicy
{

    /**
     * Determine if the given user can view the manage_i_p.
     *
     * @param UserPolicy $user
     * @param ManageIP $manage_i_p
     *
     * @return bool
     */
    public function view(UserPolicy $user, ManageIP $manage_i_p)
    {
        if ($user->canDo('manage_i_p.manage_i_p.view') && $user->isAdmin()) {
            return true;
        }

        return $manage_i_p->user_id == user_id() && $manage_i_p->user_type == user_type();
    }

    /**
     * Determine if the given user can create a manage_i_p.
     *
     * @param UserPolicy $user
     * @param ManageIP $manage_i_p
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('manage_i_p.manage_i_p.create');
    }

    /**
     * Determine if the given user can update the given manage_i_p.
     *
     * @param UserPolicy $user
     * @param ManageIP $manage_i_p
     *
     * @return bool
     */
    public function update(UserPolicy $user, ManageIP $manage_i_p)
    {
        if ($user->canDo('manage_i_p.manage_i_p.edit') && $user->isAdmin()) {
            return true;
        }

        return $manage_i_p->user_id == user_id() && $manage_i_p->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given manage_i_p.
     *
     * @param UserPolicy $user
     * @param ManageIP $manage_i_p
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ManageIP $manage_i_p)
    {
        return $manage_i_p->user_id == user_id() && $manage_i_p->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given manage_i_p.
     *
     * @param UserPolicy $user
     * @param ManageIP $manage_i_p
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ManageIP $manage_i_p)
    {
        if ($user->canDo('manage_i_p.manage_i_p.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given manage_i_p.
     *
     * @param UserPolicy $user
     * @param ManageIP $manage_i_p
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ManageIP $manage_i_p)
    {
        if ($user->canDo('manage_i_p.manage_i_p.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
